********
Overview
********

Developing plugins for Oríon is easy. We offer a plugin template powered by cookiecutter_. The
instructions are on the `template's page <https://github.com/Epistimio/cookiecutter-orion.algo>`_.

.. _cookiecutter: https://github.com/cookiecutter/cookiecutter
